############
Installation
############

ROMSearch is pip-installable: ::

  pip install romsearch

Or can be installed via GitHub for the latest version: ::

  git clone https://github.com/bbtufty/romsearch.git
  pip install -e .
